@@ -91,7 +91,7 @@ class Exceptions:
 
 class TransferClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html)
     """
 
@@ -107,7 +107,7 @@ class TransferClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#can_paginate)
         """
 
@@ -117,42 +117,42 @@ class TransferClient(BaseClient):
         Role: str,
         ServerId: str,
         ExternalId: str,
-        HomeDirectory: str = None,
-        HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
-        Policy: str = None,
-        PosixProfile: "PosixProfileTypeDef" = None
+        HomeDirectory: str = ...,
+        HomeDirectoryType: HomeDirectoryTypeType = ...,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        Policy: str = ...,
+        PosixProfile: "PosixProfileTypeDef" = ...
     ) -> CreateAccessResponseTypeDef:
         """
         Used by administrators to choose which groups in the directory should have
         access to upload and download files over the enabled protocols using Amazon Web
         Services Transfer Family.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.create_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.create_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_access)
         """
 
     def create_server(
         self,
         *,
-        Certificate: str = None,
-        Domain: DomainType = None,
-        EndpointDetails: "EndpointDetailsTypeDef" = None,
-        EndpointType: EndpointTypeType = None,
-        HostKey: str = None,
-        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = None,
-        IdentityProviderType: IdentityProviderTypeType = None,
-        LoggingRole: str = None,
-        Protocols: Sequence[ProtocolType] = None,
-        SecurityPolicyName: str = None,
-        Tags: Sequence["TagTypeDef"] = None,
-        WorkflowDetails: "WorkflowDetailsTypeDef" = None
+        Certificate: str = ...,
+        Domain: DomainType = ...,
+        EndpointDetails: "EndpointDetailsTypeDef" = ...,
+        EndpointType: EndpointTypeType = ...,
+        HostKey: str = ...,
+        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = ...,
+        IdentityProviderType: IdentityProviderTypeType = ...,
+        LoggingRole: str = ...,
+        Protocols: Sequence[ProtocolType] = ...,
+        SecurityPolicyName: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        WorkflowDetails: "WorkflowDetailsTypeDef" = ...
     ) -> CreateServerResponseTypeDef:
         """
         Instantiates an auto-scaling virtual server based on the selected file transfer
         protocol in Amazon Web Services.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.create_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.create_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_server)
         """
 
@@ -162,19 +162,19 @@ class TransferClient(BaseClient):
         Role: str,
         ServerId: str,
         UserName: str,
-        HomeDirectory: str = None,
-        HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
-        Policy: str = None,
-        PosixProfile: "PosixProfileTypeDef" = None,
-        SshPublicKeyBody: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        HomeDirectory: str = ...,
+        HomeDirectoryType: HomeDirectoryTypeType = ...,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        Policy: str = ...,
+        PosixProfile: "PosixProfileTypeDef" = ...,
+        SshPublicKeyBody: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateUserResponseTypeDef:
         """
         Creates a user and associates them with an existing file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_user)
         """
 
@@ -182,15 +182,15 @@ class TransferClient(BaseClient):
         self,
         *,
         Steps: Sequence["WorkflowStepTypeDef"],
-        Description: str = None,
-        OnExceptionSteps: Sequence["WorkflowStepTypeDef"] = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Description: str = ...,
+        OnExceptionSteps: Sequence["WorkflowStepTypeDef"] = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateWorkflowResponseTypeDef:
         """
         Allows you to create a workflow with specified steps and step details the
         workflow invokes after file transfer completes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.create_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.create_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_workflow)
         """
 
@@ -199,7 +199,7 @@ class TransferClient(BaseClient):
         Allows you to delete the access specified in the `ServerID` and `ExternalID`
         parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.delete_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.delete_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_access)
         """
 
@@ -207,7 +207,7 @@ class TransferClient(BaseClient):
         """
         Deletes the file transfer protocol-enabled server that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.delete_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.delete_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_server)
         """
 
@@ -215,7 +215,7 @@ class TransferClient(BaseClient):
         """
         Deletes a user's Secure Shell (SSH) public key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_ssh_public_key)
         """
 
@@ -224,7 +224,7 @@ class TransferClient(BaseClient):
         Deletes the user belonging to a file transfer protocol-enabled server you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_user)
         """
 
@@ -232,7 +232,7 @@ class TransferClient(BaseClient):
         """
         Deletes the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.delete_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.delete_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_workflow)
         """
 
@@ -241,7 +241,7 @@ class TransferClient(BaseClient):
         Describes the access that is assigned to the specific file transfer protocol-
         enabled server, as identified by its `ServerId` property and its `ExternalID` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.describe_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.describe_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_access)
         """
 
@@ -252,7 +252,7 @@ class TransferClient(BaseClient):
         You can use `DescribeExecution` to check the details of the execution of the
         specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.describe_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.describe_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_execution)
         """
 
@@ -263,7 +263,7 @@ class TransferClient(BaseClient):
         Describes the security policy that is attached to your file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.describe_security_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.describe_security_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_security_policy)
         """
 
@@ -272,7 +272,7 @@ class TransferClient(BaseClient):
         Describes a file transfer protocol-enabled server that you specify by passing
         the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.describe_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.describe_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_server)
         """
 
@@ -281,7 +281,7 @@ class TransferClient(BaseClient):
         Describes the user assigned to the specific file transfer protocol-enabled
         server, as identified by its `ServerId` property.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.describe_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.describe_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_user)
         """
 
@@ -289,21 +289,21 @@ class TransferClient(BaseClient):
         """
         Describes the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.describe_workflow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.describe_workflow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_workflow)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#generate_presigned_url)
         """
 
@@ -315,81 +315,81 @@ class TransferClient(BaseClient):
         `UserName` value assigned to the specific file transfer protocol-enabled server,
         identified by `ServerId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#import_ssh_public_key)
         """
 
     def list_accesses(
-        self, *, ServerId: str, MaxResults: int = None, NextToken: str = None
+        self, *, ServerId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAccessesResponseTypeDef:
         """
         Lists the details for all the accesses you have on your server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.list_accesses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.list_accesses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_accesses)
         """
 
     def list_executions(
-        self, *, WorkflowId: str, MaxResults: int = None, NextToken: str = None
+        self, *, WorkflowId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListExecutionsResponseTypeDef:
         """
         Lists all executions for the specified workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.list_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.list_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_executions)
         """
 
     def list_security_policies(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListSecurityPoliciesResponseTypeDef:
         """
         Lists the security policies that are attached to your file transfer protocol-
         enabled servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.list_security_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.list_security_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_security_policies)
         """
 
     def list_servers(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListServersResponseTypeDef:
         """
         Lists the file transfer protocol-enabled servers that are associated with your
         Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.list_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.list_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_servers)
         """
 
     def list_tags_for_resource(
-        self, *, Arn: str, MaxResults: int = None, NextToken: str = None
+        self, *, Arn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListTagsForResourceResponseTypeDef:
         """
         Lists all of the tags associated with the Amazon Resource Name (ARN) that you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_tags_for_resource)
         """
 
     def list_users(
-        self, *, ServerId: str, MaxResults: int = None, NextToken: str = None
+        self, *, ServerId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListUsersResponseTypeDef:
         """
         Lists the users for a file transfer protocol-enabled server that you specify by
         passing the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.list_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.list_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_users)
         """
 
     def list_workflows(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListWorkflowsResponseTypeDef:
         """
         Lists all of your workflows.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.list_workflows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.list_workflows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_workflows)
         """
 
@@ -399,7 +399,7 @@ class TransferClient(BaseClient):
         """
         Sends a callback for asynchronous custom steps.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.send_workflow_step_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.send_workflow_step_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#send_workflow_step_state)
         """
 
@@ -408,7 +408,7 @@ class TransferClient(BaseClient):
         Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
         `ONLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.start_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.start_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#start_server)
         """
 
@@ -417,7 +417,7 @@ class TransferClient(BaseClient):
         Changes the state of a file transfer protocol-enabled server from `ONLINE` to
         `OFFLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.stop_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.stop_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#stop_server)
         """
 
@@ -426,7 +426,7 @@ class TransferClient(BaseClient):
         Attaches a key-value pair to a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#tag_resource)
         """
 
@@ -435,16 +435,16 @@ class TransferClient(BaseClient):
         *,
         ServerId: str,
         UserName: str,
-        ServerProtocol: ProtocolType = None,
-        SourceIp: str = None,
-        UserPassword: str = None
+        ServerProtocol: ProtocolType = ...,
+        SourceIp: str = ...,
+        UserPassword: str = ...
     ) -> TestIdentityProviderResponseTypeDef:
         """
         If the `IdentityProviderType` of a file transfer protocol-enabled server is
         `AWS_DIRECTORY_SERVICE` or `API_Gateway` , tests whether your identity provider
         is set up successfully.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.test_identity_provider)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.test_identity_provider)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#test_identity_provider)
         """
 
@@ -453,7 +453,7 @@ class TransferClient(BaseClient):
         Detaches a key-value pair from a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#untag_resource)
         """
 
@@ -462,18 +462,18 @@ class TransferClient(BaseClient):
         *,
         ServerId: str,
         ExternalId: str,
-        HomeDirectory: str = None,
-        HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
-        Policy: str = None,
-        PosixProfile: "PosixProfileTypeDef" = None,
-        Role: str = None
+        HomeDirectory: str = ...,
+        HomeDirectoryType: HomeDirectoryTypeType = ...,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        Policy: str = ...,
+        PosixProfile: "PosixProfileTypeDef" = ...,
+        Role: str = ...
     ) -> UpdateAccessResponseTypeDef:
         """
         Allows you to update parameters for the access specified in the `ServerID` and
         `ExternalID` parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.update_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.update_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_access)
         """
 
@@ -481,22 +481,22 @@ class TransferClient(BaseClient):
         self,
         *,
         ServerId: str,
-        Certificate: str = None,
-        ProtocolDetails: "ProtocolDetailsTypeDef" = None,
-        EndpointDetails: "EndpointDetailsTypeDef" = None,
-        EndpointType: EndpointTypeType = None,
-        HostKey: str = None,
-        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = None,
-        LoggingRole: str = None,
-        Protocols: Sequence[ProtocolType] = None,
-        SecurityPolicyName: str = None,
-        WorkflowDetails: "WorkflowDetailsTypeDef" = None
+        Certificate: str = ...,
+        ProtocolDetails: "ProtocolDetailsTypeDef" = ...,
+        EndpointDetails: "EndpointDetailsTypeDef" = ...,
+        EndpointType: EndpointTypeType = ...,
+        HostKey: str = ...,
+        IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = ...,
+        LoggingRole: str = ...,
+        Protocols: Sequence[ProtocolType] = ...,
+        SecurityPolicyName: str = ...,
+        WorkflowDetails: "WorkflowDetailsTypeDef" = ...
     ) -> UpdateServerResponseTypeDef:
         """
         Updates the file transfer protocol-enabled server's properties after that server
         has been created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.update_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.update_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_server)
         """
 
@@ -505,22 +505,22 @@ class TransferClient(BaseClient):
         *,
         ServerId: str,
         UserName: str,
-        HomeDirectory: str = None,
-        HomeDirectoryType: HomeDirectoryTypeType = None,
-        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = None,
-        Policy: str = None,
-        PosixProfile: "PosixProfileTypeDef" = None,
-        Role: str = None
+        HomeDirectory: str = ...,
+        HomeDirectoryType: HomeDirectoryTypeType = ...,
+        HomeDirectoryMappings: Sequence["HomeDirectoryMapEntryTypeDef"] = ...,
+        Policy: str = ...,
+        PosixProfile: "PosixProfileTypeDef" = ...,
+        Role: str = ...
     ) -> UpdateUserResponseTypeDef:
         """
         Assigns new properties to a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_user)
         """
 
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/transfer.html#Transfer.Paginator.ListServers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/transfer.html#Transfer.Paginator.ListServers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
         """
