@@ -33,6 +33,7 @@ __all__ = (
     "StateType",
     "WorkflowStepTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -50,6 +51,7 @@ StateType = Literal["OFFLINE", "ONLINE", "STARTING", "START_FAILED", "STOPPING",
 WorkflowStepTypeType = Literal["COPY", "CUSTOM", "DELETE", "TAG"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -82,6 +84,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -318,10 +321,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -329,3 +334,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_servers"]
